package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.ApiResult;
import com.ruoyi.mall.domain.MallCombineGoods;

/**
 * 拼团商品Service接口
 *
 * @author ruoyi
 * @date 2024-03-21
 */
public interface IMallCombineGoodsService
{
    /**
     * 查询拼团商品
     *
     * @param combineId 拼团商品主键
     * @return 拼团商品
     */
    public MallCombineGoods selectMallCombineGoodsByCombineId(Long combineId);

    /**
     * 查询拼团商品列表
     *
     * @param mallCombineGoods 拼团商品
     * @return 拼团商品集合
     */
    public List<MallCombineGoods> selectMallCombineGoodsList(MallCombineGoods mallCombineGoods);

    /**
     * 新增拼团商品
     *
     * @param mallCombineGoods 拼团商品
     * @return 结果
     */
    public AjaxResult insertMallCombineGoods(MallCombineGoods mallCombineGoods);

    /**
     * 修改拼团商品
     *
     * @param mallCombineGoods 拼团商品
     * @return 结果
     */
    public int updateMallCombineGoods(MallCombineGoods mallCombineGoods);

    /**
     * 批量删除拼团商品
     *
     * @param combineIds 需要删除的拼团商品主键集合
     * @return 结果
     */
    public int deleteMallCombineGoodsByCombineIds(Long[] combineIds);

    /**
     * 删除拼团商品信息
     *
     * @param combineId 拼团商品主键
     * @return 结果
     */
    public int deleteMallCombineGoodsByCombineId(Long combineId);

    /**
     * 拼团商品可选商品列表
     *
     * @return 拼团商品
     */
    public List<Map<String,Object>> enableCombineGoodsList();

    /**
     * 拼团商品列表
     *
     * @return 拼团商品
     */
    public List<Map<String,Object>> getCombineGoodsList(Map<String,Object> params);
}
